from .main import *

__all__=[

]


__version__='0.0.1'
__license__='GPL-2.0 License'
__author__='Tiancheng Jiao'
__url__='https://github.com/jtc1246/myBasics'
__author_email__='jtc1246@outlook.com'
__description__='Basic tools.'


